# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/compiler.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import workflow_pb2 as flyteidl_dot_core_dot_workflow__pb2
from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x66lyteidl/core/compiler.proto\x12\rflyteidl.core\x1a\x1c\x66lyteidl/core/workflow.proto\x1a\x19\x66lyteidl/core/tasks.proto\"\x87\x03\n\rConnectionSet\x12L\n\ndownstream\x18\x07 \x03(\x0b\x32,.flyteidl.core.ConnectionSet.DownstreamEntryR\ndownstream\x12\x46\n\x08upstream\x18\x08 \x03(\x0b\x32*.flyteidl.core.ConnectionSet.UpstreamEntryR\x08upstream\x1a\x1a\n\x06IdList\x12\x10\n\x03ids\x18\x01 \x03(\tR\x03ids\x1a\x62\n\x0f\x44ownstreamEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32#.flyteidl.core.ConnectionSet.IdListR\x05value:\x02\x38\x01\x1a`\n\rUpstreamEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32#.flyteidl.core.ConnectionSet.IdListR\x05value:\x02\x38\x01\"\x8f\x01\n\x10\x43ompiledWorkflow\x12;\n\x08template\x18\x01 \x01(\x0b\x32\x1f.flyteidl.core.WorkflowTemplateR\x08template\x12>\n\x0b\x63onnections\x18\x02 \x01(\x0b\x32\x1c.flyteidl.core.ConnectionSetR\x0b\x63onnections\"G\n\x0c\x43ompiledTask\x12\x37\n\x08template\x18\x01 \x01(\x0b\x32\x1b.flyteidl.core.TaskTemplateR\x08template\"\xcd\x01\n\x17\x43ompiledWorkflowClosure\x12\x39\n\x07primary\x18\x01 \x01(\x0b\x32\x1f.flyteidl.core.CompiledWorkflowR\x07primary\x12\x44\n\rsub_workflows\x18\x02 \x03(\x0b\x32\x1f.flyteidl.core.CompiledWorkflowR\x0csubWorkflows\x12\x31\n\x05tasks\x18\x03 \x03(\x0b\x32\x1b.flyteidl.core.CompiledTaskR\x05tasksB\xad\x01\n\x11\x63om.flyteidl.coreB\rCompilerProtoP\x01Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/core\xa2\x02\x03\x46\x43X\xaa\x02\rFlyteidl.Core\xca\x02\rFlyteidl\\Core\xe2\x02\x19\x46lyteidl\\Core\\GPBMetadata\xea\x02\x0e\x46lyteidl::Coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.core.compiler_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021com.flyteidl.coreB\rCompilerProtoP\001Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/core\242\002\003FCX\252\002\rFlyteidl.Core\312\002\rFlyteidl\\Core\342\002\031Flyteidl\\Core\\GPBMetadata\352\002\016Flyteidl::Core'
  _CONNECTIONSET_DOWNSTREAMENTRY._options = None
  _CONNECTIONSET_DOWNSTREAMENTRY._serialized_options = b'8\001'
  _CONNECTIONSET_UPSTREAMENTRY._options = None
  _CONNECTIONSET_UPSTREAMENTRY._serialized_options = b'8\001'
  _globals['_CONNECTIONSET']._serialized_start=105
  _globals['_CONNECTIONSET']._serialized_end=496
  _globals['_CONNECTIONSET_IDLIST']._serialized_start=272
  _globals['_CONNECTIONSET_IDLIST']._serialized_end=298
  _globals['_CONNECTIONSET_DOWNSTREAMENTRY']._serialized_start=300
  _globals['_CONNECTIONSET_DOWNSTREAMENTRY']._serialized_end=398
  _globals['_CONNECTIONSET_UPSTREAMENTRY']._serialized_start=400
  _globals['_CONNECTIONSET_UPSTREAMENTRY']._serialized_end=496
  _globals['_COMPILEDWORKFLOW']._serialized_start=499
  _globals['_COMPILEDWORKFLOW']._serialized_end=642
  _globals['_COMPILEDTASK']._serialized_start=644
  _globals['_COMPILEDTASK']._serialized_end=715
  _globals['_COMPILEDWORKFLOWCLOSURE']._serialized_start=718
  _globals['_COMPILEDWORKFLOWCLOSURE']._serialized_end=923
# @@protoc_insertion_point(module_scope)
